@@ -696,8 +696,8 @@ int bvc_shoversion(BVS_CMD_PARAM *prm)
 {
 	int		clno;
 	struct in_addr	sin;
-	char		prline[128];
-	char		bufline[128];
+	char		prline[1024];
+	char		bufline[1024];
 	int		cnt;
 	struct timeval	curtime;
 	long		timediff;
@@ -709,13 +709,13 @@ int bvc_shoversion(BVS_CMD_PARAM *prm)
 
 	sprintf(prline, "\r\nBGPView Veriosn %s\r\n", BV_VERSION);
 	bvs_write(clno, prline);
-	sprintf(prline, "  %s\r\n", BV_COPYRIGHT);
+	sprintf(prline, "%s\r\n", BV_COPYRIGHT);
 	bvs_write(clno, prline);
-	sprintf(prline, "  All rights reserved.\r\n");
+	sprintf(prline, "All rights reserved.\r\n");
 	bvs_write(clno, prline);
 	gettimeofday(&curtime, (struct timezone *)0);
 	timediff = curtime.tv_sec - uptime.tv_sec;
-	sprintf(prline, "  System up to %s\r\n\r\n", sectoptm(timediff, bufline));
+	sprintf(prline, "System up to %s\r\n\r\n", sectoptm(timediff, bufline));
 	bvs_write(clno, prline);
 	sprintf(prline, "System Configurations:\r\n");
 	bvs_write(clno, prline);
@@ -735,20 +735,20 @@ int bvc_shoversion(BVS_CMD_PARAM *prm)
 	sprintf(prline, "  Default Spool Directory : %s\r\n", spooldir);
 	bvs_write(clno, prline);
 	if (facility == -1) {
-		sprintf(prline, "  System Logfile Name   : %s\r\n", 
+		sprintf(prline, "  System Logfile Name     : %s\r\n", 
 							syslogname);
 	} else {
-		sprintf(prline, "  Syslog Facility       : %s\r\n",
+		sprintf(prline, "  Syslog Facility         : %s\r\n",
 							&syslogname[1]);
 	}
 	bvs_write(clno, prline);
-	sprintf(prline, "  Dummuy Route Config   : %s\r\n", dmyroutef);
+	sprintf(prline, "  Dummuy Route Config     : %s\r\n", dmyroutef);
 	bvs_write(clno, prline);
 	cnt = 0;
 	while(peer[cnt].neighbor != 0) {
 		cnt++;
 	}
-	sprintf(prline, "  Configurated Peer Num.: %d\r\n", cnt);
+	sprintf(prline, "  Configurated Peer Num.  : %d\r\n", cnt);
 	bvs_write(clno, prline);
 #ifdef RTHISTORY
 	if (cleaned_time == 0) {
@@ -763,7 +763,7 @@ int bvc_shoversion(BVS_CMD_PARAM *prm)
 							rthistcleartime.tv_sec);
 	bvs_write(clno, prline);
 	if (cleaned_time_v6 == 0) {
-		bvs_write(clno, "  Last IPv6 route history clr     : Never\r\n");
+		bvs_write(clno, "  Last IPv6 route history clear  : Never\r\n");
 	} else {
 		tm = localtime(&cleaned_time);
 		strftime(bufline, TIME_BUF, "%Y/%m/%d %H:%M:%S", tm);
@@ -2457,6 +2457,671 @@ int bvc_show_bgpnexthop_sum_neighbor(BVS_CMD_PARAM *prm)
 	}
 }
 
+
+#ifdef IRRCHK
+
+void print_file_irrchk(FILE *fp, ROUTE_INFO *rinf, int proc_type)
+{
+	char		prline[1024], prbuf[1024], buf2[30];
+	struct in_addr	in;
+	IRR_ENTRY	*irrent;
+	u_long		oasn;
+        char            *bufptr, *wptr, *wptr2;
+	int		irrret;
+
+	bzero(prline, 1024);
+
+	/* Print Route Information */
+#ifdef RTHISTORY
+	if (rinf->active) {
+		strcpy(prline, "  ");
+	} else {
+		if (proc_type == 1) return;
+		strcpy(prline, "! ");
+	}
+#endif
+#ifndef RTHISTORY
+	strcpy(prline, "  ");
+#endif
+
+	if (rinf->pathset_ptr == NULL) {
+		oasn = 0;
+	} else {
+		bufptr = strdup(rinf->pathset_ptr);
+		wptr2 = NULL;
+		wptr = strtok(bufptr, " \t\r");
+		while(wptr!=NULL) {
+			wptr2 = wptr;
+			wptr = strtok(NULL, " \t\r");
+		}
+		if (wptr2 == NULL) {
+			oasn = 0;
+		} else {
+			oasn = atoi(wptr2);
+		}
+		free(bufptr);
+	}
+		
+	in.s_addr = rinf->prefix;
+
+	sprintf(buf2, "%s/%d", inet_ntoa(in), rinf->length);
+	sprintf(prbuf, "%-18s %-5lu", buf2, oasn);
+	strcat(prline, prbuf);
+
+	/* Print IRR Information */
+	irrent = rinf->irr;
+	if (irrent == NULL) {
+		/* IRR Information Not Search Yet */
+		strcat(prline, " : ----------");
+	} else {
+		irrret = irr_routecmp(&in, rinf->length, oasn, irrent);
+
+		switch(irrret) {
+		case IRR_SEARCH_FAIL:
+		case IRR_NOTMATCH:
+			strcat(prline, " :                          : ");
+			break;
+		default:
+			sprintf(buf2, "%s/%d",
+				     inet_ntoa(irrent->prefix), irrent->p_len);
+			sprintf(prbuf, " : %-18s %-5lu : ", buf2, 
+							irrent->originas);
+			strcat(prline, prbuf);
+		}
+
+
+		switch(irrret) {
+		case IRR_SEARCH_FAIL:
+			strcat(prline, "**Hmm.. IRR Search Fail?");
+			break;
+		case IRR_EXACT_AS:
+			strcat(prline, "1 : Route Exact Match");
+			break;
+		case IRR_EXACT_NOTAS:
+			strcat(prline, "3 : Route OK but, AS is not match");
+			break;
+		case IRR_MORES_AS:
+			strcat(prline, "2 : MorePrefix Mach");
+			break;
+		case IRR_MORES_NOTAS:
+			strcat(prline, "4 : MorePrefix, but AS is not match");
+			break;
+		case IRR_NOTMATCH:
+			strcat(prline, "5 : IRR not Match");
+			break;
+		}
+	}
+	fprintf(fp, "%s\n", prline);
+
+}
+
+void print_vty_irrchk(int clno, ROUTE_INFO *rinf, int proc_type)
+{
+	char		prline[1024], prbuf[1024], buf2[30];
+	struct in_addr	in;
+	IRR_ENTRY	*irrent;
+	u_long		oasn;
+        char            *bufptr, *wptr, *wptr2;
+	int		irrret;
+
+	bzero(prline, 1024);
+
+	/* Print Route Information */
+#ifdef RTHISTORY
+	if (rinf->active) {
+		strcpy(prline, "  ");
+	} else {
+		if (proc_type == 1) return;
+		strcpy(prline, "! ");
+	}
+#endif
+#ifndef RTHISTORY
+	strcpy(prline, "  ");
+#endif
+
+	if (rinf->pathset_ptr == NULL) {
+		oasn = 0;
+	} else {
+		bufptr = strdup(rinf->pathset_ptr);
+		wptr2 = NULL;
+		wptr = strtok(bufptr, " \t\r");
+		while(wptr!=NULL) {
+			wptr2 = wptr;
+			wptr = strtok(NULL, " \t\r");
+		}
+		if (wptr2 == NULL) {
+			oasn = 0;
+		} else {
+			oasn = atoi(wptr2);
+		}
+		free(bufptr);
+	}
+		
+	in.s_addr = rinf->prefix;
+
+	sprintf(buf2, "%s/%d", inet_ntoa(in), rinf->length);
+	sprintf(prbuf, "%-18s %-5lu", buf2, oasn);
+	strcat(prline, prbuf);
+
+	/* Print IRR Information */
+	irrent = rinf->irr;
+	if (irrent == NULL) {
+		/* IRR Information Not Search Yet */
+		strcat(prline, " : ----------\r\n");
+	} else {
+		irrret = irr_routecmp(&in, rinf->length, oasn, irrent);
+
+		switch(irrret) {
+		case IRR_SEARCH_FAIL:
+		case IRR_NOTMATCH:
+			strcat(prline, " :                          : ");
+			break;
+		default:
+			sprintf(buf2, "%s/%d",
+				     inet_ntoa(irrent->prefix), irrent->p_len);
+			sprintf(prbuf, " : %-18s %-5lu : ", buf2, 
+							irrent->originas);
+			strcat(prline, prbuf);
+		}
+
+
+		switch(irrret) {
+		case IRR_SEARCH_FAIL:
+			strcat(prline, "**Hmm.. IRR Search Fail?\r\n");
+			break;
+		case IRR_EXACT_AS:
+			strcat(prline, "1 : Route Exact Match\r\n");
+			break;
+		case IRR_EXACT_NOTAS:
+			strcat(prline, "3 : Route OK but, AS is not match\r\n");
+			break;
+		case IRR_MORES_AS:
+			strcat(prline, "2 : MorePrefix Mach\r\n");
+			break;
+		case IRR_MORES_NOTAS:
+			strcat(prline, "4 : MorePrefix, but AS is not match\r\n");
+			break;
+		case IRR_NOTMATCH:
+			strcat(prline, "5 : IRR not Match\r\n");
+			break;
+		}
+	}
+	bvs_write(clno, prline);
+
+}
+
+void print_file_irr_status(FILE *fp, R_LIST *ri, int proc_type)
+{
+	R_LIST		*rlptr;
+	ROUTE_INFO	*rinf;
+
+	rlptr = ri;
+	while(rlptr != NULL) {
+		rinf = rlptr->route_data;
+
+		print_file_irrchk(fp, rinf, proc_type);
+
+		rlptr = rlptr->next;
+	}
+
+	fclose(fp);
+
+}
+
+void print_irr_status(int clno, R_LIST *ri, int proc_type)
+{
+	R_LIST		*rlptr;
+	ROUTE_INFO	*rinf;
+
+	rlptr = ri;
+	while(rlptr != NULL) {
+		rinf = rlptr->route_data;
+
+		print_vty_irrchk(clno, rinf, proc_type);
+
+		rlptr = rlptr->next;
+	}
+}
+
+int proc_do_output_irr_status(BVS_CMD_PARAM *prm, int proc_type)
+{
+	int		clno;
+	static RADIX_T	**cnode;
+	static int	*upcode;
+	RADIX_T		*node;
+	char		fname[FNAMESIZE];
+	char		fn[FNAMESIZE];
+	static FILE	*fp;
+
+	if (prm == NULL) {
+		cnode = (RADIX_T **)malloc(sizeof(RADIX_T *) * bvs_maxcon);
+		bzero(cnode, sizeof(RADIX_T *) * bvs_maxcon);
+		upcode = (int *)malloc(sizeof(int) * bvs_maxcon);
+		bzero(upcode, sizeof(int) * bvs_maxcon);
+		return(0);
+	}
+
+	if (irr_check_enable == 0) {
+		bvs_write(clno, "IRR Check Disabled\r\n");
+		return(BVS_CNT_END);
+	}
+
+	clno = (prm->noparam).clno;
+	strcpy(fn, (prm->one_str64).str);
+	if (fn[0] == '/') {
+		strcpy(fname, fn);
+	} else {
+		strcpy(fname, spooldir);
+		strcat(fname, "/");
+		strcat(fname, fn);
+	}
+
+	if (*(cnode+clno) == NULL) {
+		if ((fp = fopen(fname, "w")) == NULL) {
+			bvs_write(clno, "Could not open target file.\r\n");
+			return(BVS_CNT_END);
+		}
+
+		bvs_write(clno, "Now Outputting Routes to '");
+		bvs_write(clno, fname);
+		bvs_write(clno, "'\r\n");
+
+		fprintf(fp, "\r\n ! : Inactive Route\r\n\r\n");
+		fprintf(fp, 
+"  Prefix             ASN   : IRR Prefix         ASN   : Compare Result\r\n");
+	}
+
+	node = show_route_all(*(cnode+clno), (upcode+clno));
+	if (node == NULL) {
+		if (*(cnode+clno) == NULL) {
+			fprintf(fp, "%% No Route\r\n");
+		}
+	} else {
+		print_file_irr_status(fp, node->rinfo, proc_type);
+	}
+	if (node == NULL) {
+		if (*(cnode+clno) == NULL) {
+			*(cnode+clno) = node;
+			fclose(fp);
+			bvs_write(clno, "Done(No Route)..\r\n");
+			return(BVS_CNT_END);
+		} else {
+			*(cnode+clno) = node;
+			fclose(fp);
+			bvs_write(clno, "Done..\r\n");
+			return(BVS_CNT_FINISH);
+		}
+	} else {
+		*(cnode+clno) = node;
+		return(BVS_CNT_CONTINUE);
+	}
+}
+
+int bvc_do_output_irr_status(BVS_CMD_PARAM *prm)
+{
+	proc_do_output_irr_status(prm, 0);
+}
+
+int bvc_do_output_irr_status_active(BVS_CMD_PARAM *prm)
+{
+	proc_do_output_irr_status(prm, 1);
+}
+
+/******* Added at 2006/09/07 *******/
+int proc_show_irr_status(BVS_CMD_PARAM *prm, int proc_type)
+{
+	int		clno;
+	static RADIX_T	**cnode;
+	static int	*upcode;
+	RADIX_T		*node;
+
+	if (prm == NULL) {
+		cnode = (RADIX_T **)malloc(sizeof(RADIX_T *) * bvs_maxcon);
+		bzero(cnode, sizeof(RADIX_T *) * bvs_maxcon);
+		upcode = (int *)malloc(sizeof(int) * bvs_maxcon);
+		bzero(upcode, sizeof(int) * bvs_maxcon);
+		return(0);
+	}
+
+	if (irr_check_enable == 0) {
+		bvs_write(clno, "IRR Check Disabled\r\n");
+		return(BVS_CNT_END);
+	}
+
+	clno = (prm->noparam).clno;
+
+	if (*(cnode+clno) == NULL) {
+		bvs_write(clno, "\r\n ! : Inactive Route\r\n\r\n");
+		bvs_write(clno, 
+"  Prefix             ASN   : IRR Prefix         ASN   : Compare Result\r\n");
+	}
+
+	node = show_route_all(*(cnode+clno), (upcode+clno));
+	if (node == NULL) {
+		if (*(cnode+clno) == NULL) {
+			bvs_write(clno, "%% No Route\r\n");
+		}
+	} else {
+		print_irr_status(clno, node->rinfo, proc_type);
+	}
+	if (node == NULL) {
+		if (*(cnode+clno) == NULL) {
+			*(cnode+clno) = node;
+			return(BVS_CNT_END);
+		} else {
+			*(cnode+clno) = node;
+			return(BVS_CNT_FINISH);
+		}
+	} else {
+		*(cnode+clno) = node;
+		return(BVS_CNT_CONTINUE);
+	}
+}
+
+int bvc_show_irr_status(BVS_CMD_PARAM *prm)
+{
+	proc_show_irr_status(prm, 0);
+}
+
+int bvc_show_irr_status_active(BVS_CMD_PARAM *prm)
+{
+	proc_show_irr_status(prm, 1);
+}
+
+int check_irr_stats(ROUTE_INFO *rinf)
+{
+	int		stret;
+        struct in_addr  in;
+        IRR_ENTRY       *irrent;
+        u_long          oasn;
+        char            *bufptr, *wptr, *wptr2;
+        int             irrret;
+
+	stret = 0;
+
+#ifdef RTHISTORY 
+	/* Only Count Active route */
+	if (!(rinf->active)) return(-1);
+#endif
+
+        if (rinf->pathset_ptr == NULL) {
+                oasn = 0;
+        } else {
+                bufptr = strdup(rinf->pathset_ptr);
+                wptr2 = NULL;
+                wptr = strtok(bufptr, " \t\r");
+                while(wptr!=NULL) {
+                        wptr2 = wptr;
+                        wptr = strtok(NULL, " \t\r");
+                }
+                if (wptr2 == NULL) {
+                        oasn = 0;
+                } else {
+                        oasn = atoi(wptr2);
+                }
+		free(bufptr);
+        }
+                
+        in.s_addr = rinf->prefix;
+
+        /* Print IRR Information */
+        irrent = rinf->irr;
+        if (irrent == NULL) {
+                /* IRR Information Not Search Yet */
+                stret = 0;
+        } else {
+                irrret = irr_routecmp(&in, rinf->length, oasn, irrent);
+
+                switch(irrret) {
+                case IRR_SEARCH_FAIL:
+                        stret = 0;
+                        break;
+                case IRR_EXACT_AS:
+                case IRR_EXACT_NOTAS:
+                case IRR_MORES_AS:
+                case IRR_MORES_NOTAS:
+                case IRR_NOTMATCH:
+			stret = irrret;
+                        break;
+                }
+        }
+	return(stret);
+}
+
+int bvc_show_irr_status_summary(BVS_CMD_PARAM *prm)
+{
+	/* This Function Counts Only Active Routes */
+
+        int             clno;
+        static RADIX_T  **cnode;
+        static int      *upcode;
+        RADIX_T         *node;
+        char            prline[FNAMESIZE];
+        static FILE     *fp;
+	static u_long	*statscnt; /* max type number */
+	int		retstats;
+	R_LIST		*rlptr;
+	ROUTE_INFO	*rinf;
+	static int      *bcnt;
+	static char     bc[4] = "-\\|/";
+
+        if (prm == NULL) {
+                cnode = (RADIX_T **)malloc(sizeof(RADIX_T *) * bvs_maxcon);
+                bzero(cnode, sizeof(RADIX_T *) * bvs_maxcon);
+                upcode = (int *)malloc(sizeof(int) * bvs_maxcon);
+                bzero(upcode, sizeof(int) * bvs_maxcon);
+		statscnt = (u_long *)malloc(sizeof(u_long) * 6 * bvs_maxcon);
+		bzero(statscnt, sizeof(statscnt) * bvs_maxcon);
+		bcnt = (int *)malloc(sizeof(int) * bvs_maxcon);
+		bzero(bcnt, sizeof(int) * bvs_maxcon);
+                return(0);
+        }
+
+        if (irr_check_enable == 0) {
+                bvs_write(clno, "IRR Check Disabled\r\n");
+                return(BVS_CNT_END);
+        }
+
+        clno = (prm->noparam).clno;
+
+        if (*(cnode+clno) == NULL) {
+                bvs_write(clno, "Now Counting IRR Status Summary ... -");
+		*(statscnt+(clno*6)+0) = 0;
+		*(statscnt+(clno*6)+1) = 0;
+		*(statscnt+(clno*6)+2) = 0;
+		*(statscnt+(clno*6)+3) = 0;
+		*(statscnt+(clno*6)+4) = 0;
+		*(statscnt+(clno*6)+5) = 0;
+		*(bcnt+clno) = 0;
+        }
+
+        node = show_route_all(*(cnode+clno), (upcode+clno));
+        if (node == NULL) {
+                if (*(cnode+clno) == NULL) {
+                        bvs_write(clno, "%% No Route\r\n");
+                }
+        } else {
+		rlptr = node->rinfo;
+
+		sprintf(prline, "\b%c", bc[*(bcnt+clno)]);
+		bvs_write(clno, prline);
+		(*(bcnt+clno))++;
+		if (*(bcnt+clno) >= 4) *(bcnt+clno) = 0;
+
+		while(rlptr != NULL) {
+			rinf = rlptr->route_data;
+                	retstats = check_irr_stats(rinf /*, proc_type */);
+			if (retstats >= 0) (*(statscnt+(clno*6)+retstats))++;
+#ifdef DEBUG
+			if (retstats >= 0)
+			pr_log2(VLOG_GLOB, LOG_ALL, ON,
+				"DEBUG: IRR Stats Sum:%d:retstats=%d/cnt=%ld\n",
+				 clno, retstats, *(statscnt+(clno*6)+retstats));
+#endif
+			rlptr = rlptr->next;
+		}
+        }
+        if (node == NULL) {
+                if (*(cnode+clno) == NULL) {
+                        *(cnode+clno) = node;
+			bvs_write(clno, "\bDone(No Route).\r\n");
+                        return(BVS_CNT_END);
+                } else {
+                        *(cnode+clno) = node;
+                        bvs_write(clno, "\bDone.\r\n");
+	
+                        bvs_write(clno, "Status                             : Routes\r\n");
+			sprintf(prline, "-: Non-Count Route                 : %-7d routes\r\n", *(statscnt+(clno*6)+0));
+                        bvs_write(clno, prline);
+			sprintf(prline, "1: Route Exact Match               : %-7d routes\r\n", *(statscnt+(clno*6)+1));
+                        bvs_write(clno, prline);
+			sprintf(prline, "2: MorePrefix Match                : %-7d routes\r\n", *(statscnt+(clno*6)+2));
+                        bvs_write(clno, prline);
+			sprintf(prline, "3: Route OK but, AS is not match   : %-7d routes\r\n", *(statscnt+(clno*6)+3));
+                        bvs_write(clno, prline);
+			sprintf(prline, "4: MorePrefix, but AS is not match : %-7d routes\r\n", *(statscnt+(clno*6)+4));
+                        bvs_write(clno, prline);
+			sprintf(prline, "5: IRR not Match                   : %-7d routes\r\n", *(statscnt+(clno*6)+5));
+                        bvs_write(clno, prline);
+                        bvs_write(clno, "\r\n");
+
+                        return(BVS_CNT_FINISH);
+                }
+        } else {
+                *(cnode+clno) = node;
+                return(BVS_CNT_CONTINUE);
+        }
+}
+
+
+#endif /* IRRCHK */
+
+
+/************** Add by K.Kondo 2006/11/09 for Flow Inspection Proj ******/
+
+int bvc_output_aslist_nei(BVS_CMD_PARAM *prm)
+/***
+#ifdef RTHISTORY
+int output_bgproute_nei(BVS_CMD_PARAM *prm, boolean detail, int dtype)
+#endif
+#ifndef RTHISTORY
+int bvc_output_bgproute_all_nei(BVS_CMD_PARAM *prm)
+#endif
+****/
+{
+	int		clno;
+	static RADIX_T	**cnode;
+	static int	*upcode;
+	RADIX_T		*node;
+	char		fname[FNAMESIZE];
+	char		fn[FNAMESIZE];
+	static FILE	*fp;
+	u_long		neighbor;
+	char		*bufptr, *wptr, *wptr2;
+	R_LIST		*rl;
+	ROUTE_INFO	*ri;
+	u_long		oasn;
+	struct in_addr	in;
+
+	if (prm == NULL) {
+		cnode = (RADIX_T **)malloc(sizeof(RADIX_T *) * bvs_maxcon);
+		bzero(cnode, sizeof(RADIX_T *) * bvs_maxcon);
+		upcode = (int *)malloc(sizeof(int) * bvs_maxcon);
+		bzero(upcode, sizeof(int) * bvs_maxcon);
+		return(0);
+	}
+
+	clno = (prm->one_str64_adrs).clno;
+	strcpy(fn, (prm->one_str64_adrs).str);
+	neighbor = (prm->one_str64_adrs).addr;
+
+	if (fn[0] == '/') {
+		strcpy(fname, fn);
+	} else {
+		strcpy(fname, spooldir);
+		strcat(fname, "/");
+		strcat(fname, fn);
+	}
+
+	if (*(cnode+clno) == NULL) {
+		if ((fp = fopen(fname, "w")) == NULL) {
+			bvs_write(clno, "Could not open target file.\r\n");
+			return(BVS_CNT_END);
+		}
+
+		bvs_write(clno, "Now Outputting Routes to '");
+		bvs_write(clno, fname);
+		bvs_write(clno, "'\r\n");
+		/******
+		fprintf(fp, 
+"   Prefix           Next Hop         Metric Loc_Pef Time    AS_Path\n");
+		*******/
+	}
+
+	node = show_route_all(*(cnode+clno), (upcode+clno));
+	if (node == NULL) {
+		if (*(cnode+clno) == NULL) {
+			fprintf(fp, "%% No Route\n");
+		}
+	} else {
+/******
+#ifdef RTHISTORY
+		output_routesum(node->rinfo, neighbor, fp, detail, dtype);
+#endif
+#ifndef RTHISTORY
+		output_routesum(node->rinfo, neighbor, fp);
+#endif
+*******/
+		/***** This Part is printing AS List *****/
+		rl = node->rinfo;
+		while(rl != NULL) {
+			ri = rl->route_data;
+			if (ri->source != neighbor) continue;
+
+			bufptr = strdup(ri->pathset_ptr);
+			wptr2 = NULL;
+			wptr = strtok(bufptr, " \t\r");
+			while(wptr != NULL) {
+				wptr2 = wptr;
+				wptr = strtok(NULL, " \t\r");
+			}
+			if (wptr2 == NULL) {
+				oasn = 0;
+			} else {
+				oasn = atoi(wptr2);
+			}
+
+			in.s_addr = ri->prefix;
+
+
+			fprintf(fp, "%lu:%s/%d\n", 
+				oasn, inet_ntoa(in), ri->length);
+				
+			free(bufptr);
+
+			rl = rl->next;
+		}
+	}
+	if (node == NULL) {
+		if (*(cnode+clno) == NULL) {
+			*(cnode+clno) = node;
+			fclose(fp);
+			bvs_write(clno, "Done(No Route)..\r\n");
+			return(BVS_CNT_END);
+		} else {
+			*(cnode+clno) = node;
+			fclose(fp);
+			bvs_write(clno, "Done..\r\n");
+			return(BVS_CNT_FINISH);
+		}
+	} else {
+		*(cnode+clno) = node;
+		return(BVS_CNT_CONTINUE);
+	}
+}
+
+/************************** Add end 2006/11/09 ************************/
+
 #ifdef DEBUG
 
 #ifdef RADIX
@@ -2478,10 +3143,10 @@ int bvc_dodeleteroute(BVS_CMD_PARAM *prm)
 
 #ifdef RTHISTORY
 	r = withdraw_route(pn, pref, mask, DELETE);
-#endif
+#endif /* RTHISTORY */
 #ifndef RTHISTORY
 	r = withdraw_route(pn, pref, mask);
-#endif
+#endif /* RTHISTORY */
 	if (r == 0) {
 		bvs_write(clno, "Route Withdraw Successful\r\n");
 	} else {
@@ -2509,6 +3174,7 @@ int bvc_doclearpeerroute(BVS_CMD_PARAM *prm)
 
 #endif /* RADIX */
 
+
 int bvc_dotimertest(BVS_CMD_PARAM *prm)
 {
 	int		clno;
