@@ -140,6 +140,18 @@ char capability_check(char *param, char length, int pn)
 			case SAFI_NLRI_UNI:
 				opterr = 0;
 				break;
+			case SAFI_NLRI_MULTI:
+				/* Beta0.38 : Multicast is not supported
+                                   But, ignore this */
+				opterr = 0;
+				break;
+			case SAFI_NLRI_BOTH:
+				/* Beta0.38 : Multicast is not supported
+                                   But, ignore this */
+				opterr = 0;
+				break;
+			case SAFI_NLRI_MPLS:
+				/* Capability Error */
 			default:
 				pr_log(VLOG_GLOB, pn, "CAPACHK: Unsupported Capability\n", ON);
 				opterr = UNSUPPORTED_CAPABILITY;
